@@ -30,16 +30,23 @@ describe 'gnocchi' do
       it 'does not configure coordination_url' do
         is_expected.to contain_gnocchi_config('DEFAULT/coordination_url').with_value('<SERVICE DEFAULT>').with_secret(true)
         is_expected.to contain_oslo__coordination('gnocchi_config').with(
-          :backend_url   => '<SERVICE DEFAULT>',
-          :manage_config => false,
+          :backend_url            => '<SERVICE DEFAULT>',
+          :manage_backend_package => true,
+          :package_ensure         => 'present',
+          :manage_config          => false,
         )
       end
     end
 
     context 'with overridden parameters' do
       let :params do
-        { :purge_config     => true,
-          :coordination_url => 'redis://localhost:6379', }
+        {
+          :purge_config           => true,
+          :coordination_url       => 'redis://localhost:6379',
+          :package_ensure         => 'installed',
+          :manage_backend_package => false,
+          :backend_package_ensure => 'latest',
+        }
       end
 
       it 'purges gnocchi config' do
@@ -48,11 +55,21 @@ describe 'gnocchi' do
         })
       end
 
+      it 'installs packages' do
+        is_expected.to contain_package('gnocchi').with(
+          :name   => platform_params[:gnocchi_common_package],
+          :ensure => 'installed',
+          :tag    => ['openstack', 'gnocchi-package']
+        )
+      end
+
       it 'configures coordination' do
         is_expected.to contain_gnocchi_config('DEFAULT/coordination_url').with_value('redis://localhost:6379').with_secret(true)
         is_expected.to contain_oslo__coordination('gnocchi_config').with(
-          :backend_url   => 'redis://localhost:6379',
-          :manage_config => false,
+          :backend_url            => 'redis://localhost:6379',
+          :manage_backend_package => false,
+          :package_ensure         => 'latest',
+          :manage_config          => false,
         )
       end
     end
