@@ -24,8 +24,11 @@ describe 'gnocchi::statsd' do
 
     it 'configures gnocchi statsd' do
       is_expected.to contain_gnocchi_config('statsd/resource_id').with_value('07f26121-5777-48ba-8a0b-d70468133dd9')
+      is_expected.to contain_gnocchi_config('statsd/host').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_gnocchi_config('statsd/port').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_gnocchi_config('statsd/flush_delay').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_gnocchi_config('statsd/archive_policy_name').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_gnocchi_config('statsd/creator').with_value('<SERVICE DEFAULT>')
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
@@ -59,6 +62,20 @@ describe 'gnocchi::statsd' do
       end
     end
 
+    context 'whth host and port' do
+      before do
+        params.merge!({
+          :host => '192.0.2.1',
+          :port => 8125,
+        })
+      end
+
+      it 'configures the parameter' do
+        is_expected.to contain_gnocchi_config('statsd/host').with_value('192.0.2.1')
+        is_expected.to contain_gnocchi_config('statsd/port').with_value(8125)
+      end
+    end
+
     context 'with flush_delay' do
       before do
         params.merge!({ :flush_delay => 10 })
@@ -78,6 +95,16 @@ describe 'gnocchi::statsd' do
         is_expected.to contain_gnocchi_config('statsd/archive_policy_name').with_value('high')
       end
     end
+
+    context 'with creator' do
+      before do
+        params.merge!({ :creator => 'creator' })
+      end
+
+      it 'configures the parameter' do
+        is_expected.to contain_gnocchi_config('statsd/creator').with_value('creator')
+      end
+    end
   end
 
   on_supported_os({
